;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "keycast" "1.4.7"
  "Show current command and its binding."
  '((emacs  "28.1")
    (compat "30.1"))
  :url "https://github.com/tarsius/keycast"
  :commit "b831e380c4deb1d51ce5db0a965b96427aec52e4"
  :revdesc "v1.4.7-0-gb831e380c4de"
  :keywords '("multimedia")
  :authors '(("Jonas Bernoulli" . "emacs.keycast@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.keycast@jonas.bernoulli.dev")))
